% function [nugapvec] = freqgapmetric(P1,P2,omega)
%
% Compute the nu-gap metric on a frequency grid between to LTI systems P1 and
% P2
%
% P1: ss-object of first LTI system
% P2: ss-object of second LTI system
% omega: vector of frequency points

function [nugapvec] = freqgapmetric(P1,P2,omega)

%create freq response of both plants
P1resp = frdata(frd(P1,omega));
P2resp = frdata(frd(P2,omega));

%at each frequency point compute the nugap-metric
nugapvec = zeros(1,length(omega));
for ii = 1:length(omega)
    
    tmp1 = (eye(size(P2,1))+P2resp(:,:,ii)*P2resp(:,:,ii)')^(-.5);
    tmp2 = (eye(size(P1,2))+P1resp(:,:,ii)'*P1resp(:,:,ii))^(-.5);
    nugapvec(ii) = norm(tmp1*(P2resp(:,:,ii)-P1resp(:,:,ii))*tmp2,2);
end


end

